
Astrocut
========

Tools for making image cutouts from sets of TESS full frame images.

This package is under active development, and will ultimately grow to encompass a range of cutout activities relevant to images from many missions, however at this time it is focussed on the specific problem of creating Target Pixel File cutouts from sectors of TESS full frame images.

Documentation
-------------

.. toctree::
  :maxdepth: 2

  astrocut/install.rst

.. toctree::
  :maxdepth: 3

  astrocut/index.rst


.. toctree::
  :maxdepth: 1

  license
